### csv_dispatcher

Run a python function based on a csv with input for it.
More generally, apply a function to parameters specified in data frame.


![](https://github.com/MatteoLacki/csv_dispatcher/blob/main/manual.jpg?raw=true)

